@@ -26,11 +26,21 @@ __copyright__ = """
 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 """
 
-__version__ = "2020.11.30"
+__version__ = "2020.12.7"
 
 repo_root = pathlib.Path(__file__).parent
 install_requires = (repo_root / "requirements.txt").read_text(encoding="utf-8").split('\n')
 extras_require = {
-		"testing": ["pytest>=6.0.0", "domdf-python-tools[testing]>=1.5.0"],
-		"all": ["domdf-python-tools[testing]>=1.5.0", "pytest>=6.0.0"]
+		"testing": [
+				"pytest>=6.0.0",
+				"domdf-python-tools[testing]>=1.6.0",
+				"twine>=3.2.0",
+				"check_wheel_contents>=0.2.0"
+				],
+		"all": [
+				"check_wheel_contents>=0.2.0",
+				"domdf-python-tools[testing]>=1.6.0",
+				"pytest>=6.0.0",
+				"twine>=3.2.0"
+				]
 		}
