@@ -50,6 +50,7 @@ __all__ = [
 		"create_docs_install_block",
 		"get_docs_links_block_template",
 		"create_docs_links_block",
+		"get_readme_installation_block_no_pypi_template",
 		]
 
 #: Regular expression to match the installation block placeholder.
@@ -172,6 +173,18 @@ def get_readme_installation_block_template() -> Template:
 	return template_from_file("readme_installation_block_template.rst")
 
 
+@functools.lru_cache(1)
+def get_readme_installation_block_no_pypi_template() -> Template:
+	"""
+	Loads the readme_installation_block_no_pypi template from file
+	and returns a jinja2 :class:`jinja2.environment.Template` for it.
+
+	.. versionadded:: 2020.12.1
+	"""  # noqa: D400
+
+	return template_from_file("readme_installation_block_no_pypi_template.rst")
+
+
 @functools.lru_cache(1)
 def get_docs_links_block_template() -> Template:
 	"""
@@ -200,7 +213,7 @@ def create_shields_block(
 		conda: bool = True,
 		tests: bool = True,
 		docs: bool = True,
-		travis_site: Literal["com", "org"] = "com",
+		docs_url: str = "https://{}.readthedocs.io/en/latest/?badge=latest",
 		pypi_name: Optional[str] = None,
 		unique_name: str = '',
 		docker_shields: bool = False,
@@ -219,7 +232,7 @@ def create_shields_block(
 	:param conda:
 	:param tests:
 	:param docs:
-	:param travis_site:
+	:param docs_url:
 	:param pypi_name: The name of the project on PyPI. Defaults to the value of ``repo_name`` if unset.
 	:param unique_name: An optional unique name for the reST substitutions.
 	:param docker_shields: Whether to show shields for Docker. Default :py:obj:`False`.
@@ -232,6 +245,8 @@ def create_shields_block(
 	:return: The shields block created from the above settings.
 	"""
 
+	docs_url = docs_url.format(repo_name.lower())
+
 	if unique_name and not unique_name.startswith('_'):
 		unique_name = f"_{unique_name}"
 
@@ -255,6 +270,7 @@ def create_shields_block(
 			platforms=platforms,
 			pre_commit=pre_commit,
 			on_pypi=on_pypi,
+			docs_url=docs_url,
 			)
 
 
