@@ -55,6 +55,7 @@ from repo_helper.configuration import (
 from repo_helper.configuration.conda_anaconda import conda_channels, conda_description, conda_extras, enable_conda
 from repo_helper.configuration.documentation import (
 		docs_dir,
+		docs_url,
 		enable_docs,
 		extra_sphinx_extensions,
 		html_context,
@@ -225,6 +226,7 @@ __all__ = [
 		"standalone_contrib_guide",
 		"assignee",
 		"YamlEditor",
+		"docs_url",
 		]
 
 
@@ -328,10 +330,9 @@ class RepoHelperParser(Parser):
 		py_versions = parsed_config_vars["python_versions"]
 		tox_py_versions = get_tox_python_versions(py_versions)
 		parsed_config_vars["tox_py_versions"] = tox_py_versions
-		tox_travis_versions = get_tox_travis_python_versions(py_versions, tox_py_versions)
-		tox_travis_versions[parsed_config_vars["python_deploy_version"]] += ", mypy"
-		parsed_config_vars["tox_travis_versions"] = tox_travis_versions
-		parsed_config_vars["gh_actions_versions"] = tox_travis_versions
+		gh_actions_versions = get_gh_actions_python_versions(py_versions, tox_py_versions)
+		parsed_config_vars["tox_travis_versions"] = gh_actions_versions
+		parsed_config_vars["gh_actions_versions"] = gh_actions_versions
 
 		if (repo_path / parsed_config_vars["import_name"].replace('.', '/') / "py.typed").is_file():
 			parsed_config_vars["classifiers"].append("Typing :: Typed")
@@ -341,6 +342,10 @@ class RepoHelperParser(Parser):
 
 		parsed_config_vars["classifiers"] = natsorted(set(parsed_config_vars["classifiers"]))
 
+		if parsed_config_vars["docs_url"] is None:
+			url = f"https://{parsed_config_vars['repo_name'].lower()}.readthedocs.io/en/latest"
+			parsed_config_vars["docs_url"] = url
+
 		return parsed_config_vars
 
 
