@@ -35,7 +35,6 @@ __all__ = [
 		"manifest_additional",
 		"py_modules",
 		"console_scripts",
-		"parse_additional_setup_args",
 		"additional_setup_args",
 		"extras_require",
 		"entry_points",
@@ -80,7 +79,7 @@ class py_modules(ConfigVar):  # noqa
 	category: str = "packaging"
 
 	@classmethod
-	def validate(cls, raw_config_vars: Optional[Dict[str, Any]] = None) -> Any:
+	def validate(cls, raw_config_vars: Optional[Dict[str, Any]] = None) -> List[str]:  # noqa: D102
 		modules = super().validate(raw_config_vars)
 
 		if modules:
@@ -131,8 +130,8 @@ class entry_points(ConfigVar):  # noqa
 	category: str = "packaging"
 
 
-def parse_additional_setup_args(setup_args: Mapping[str, Any]):
-	return "\n".join(["\t\t{}={},".format(*x) for x in setup_args.items()])
+# def parse_additional_setup_args(setup_args: Mapping[str, Any]):
+# 	return '\n'.join(["\t\t{}={},".format(*x) for x in setup_args.items()])
 
 
 class additional_setup_args(ConfigVar):  # noqa
@@ -189,7 +188,9 @@ class extras_require(ConfigVar):  # noqa
 
 class additional_requirements_files(ConfigVar):  # noqa
 	"""
-	A list of files containing additional requirements. These may define "extras" (see :conf:`extras_require`). Used in ``.readthedocs.yml``.
+	A list of files containing additional requirements.
+
+	These may define "extras" (see :conf:`extras_require`). Used in ``.readthedocs.yml``.
 
 	Example:
 
@@ -266,6 +267,7 @@ class use_experimental_backend(ConfigVar):  # noqa
 	def validate(cls, raw_config_vars: Optional[Dict[str, Any]] = None) -> Any:  # noqa: D102
 
 		# this package
+		from repo_helper.configuration import desktopfile
 		from repo_helper.configuration.metadata import pure_python
 		from repo_helper.configuration.other import exclude_files
 
@@ -279,6 +281,7 @@ class use_experimental_backend(ConfigVar):  # noqa
 				additional_setup_args,
 				setup_pre,
 				py_modules,
+				desktopfile,
 				)
 
 		for key in disallowed_keys:
