@@ -39,10 +39,10 @@ import repo_helper.files
 from repo_helper.configuration import parse_yaml
 from repo_helper.files import Management, is_registered, management
 from repo_helper.files.docs import copy_docs_styling
-from repo_helper.files.linting import code_only_warning, lint_fix_list, lint_warn_list
+from repo_helper.files.linting import code_only_warning, lint_warn_list
 from repo_helper.files.testing import make_isort
 from repo_helper.templates import init_repo_template_dir, template_dir
-from repo_helper.utils import discover_entry_points
+from repo_helper.utils import brace, discover_entry_points
 
 __all__ = [
 		"RepoHelper",
@@ -92,6 +92,7 @@ class RepoHelper:
 			undefined=jinja2.StrictUndefined,
 			)
 		self.templates.globals["managed_message"] = managed_message
+		self.templates.globals["brace"] = brace
 
 		self.load_settings()
 
@@ -121,7 +122,6 @@ class RepoHelper:
 
 		config_vars = parse_yaml(self.target_repo)
 		self.templates.globals.update(config_vars)
-		self.templates.globals["lint_fix_list"] = lint_fix_list
 		self.templates.globals["lint_warn_list"] = lint_warn_list
 		self.templates.globals["code_only_warning"] = code_only_warning
 		self.templates.globals["enquote_value"] = enquote_value
